@@ -14,15 +14,16 @@ def get_tiddler_locations(store_contents, package):
 	instance_tiddlers = []
 	try:
 		filepaths = []
-		with open(tiddler_index) as f:
-			for line in f:
-				bag, filename = line.rstrip().split("/", 1)
-				filepath = os.path.join("resources", bag, filename)
-				uri = "file:%s" % resource_filename(package, filepath)
-				filepaths.append(uri)
-				if filename.endswith(".js"): # unpack meta files into egg cache
-					resource_filename(package, "%s.meta" % filepath)
-				instance_tiddlers.append((bag, filepaths))
+		f = open(tiddler_index)
+		for line in f:
+			bag, filename = line.rstrip().split("/", 1)
+			filepath = os.path.join("resources", bag, filename)
+			uri = "file:%s" % resource_filename(package, filepath)
+			filepaths.append(uri)
+			if filename.endswith(".js"): # unpack meta files into egg cache
+				resource_filename(package, "%s.meta" % filepath)
+			instance_tiddlers.append((bag, filepaths))
+		f.close()
 	except IOError:
 		for bag, uris in store_contents.items():
 			instance_tiddlers.append((bag, uris))
